==> HinemosWebClient_src-2.0.1.tar.gz: HinemosWebClient_src-2.0.1/src/com/necsoft/hinemos/webclient/json/GridHeaderJson.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.json;

import java.util.List;
import java.util.Map;

public class GridHeaderJson extends CommonJson {
    private List<String> colNames;

    private List<Map<String, Object>> colModel;

    private int rowNum;

    private String sortname;

    private String sortorder;

    private String recordtext;

    private String emptyrecords;

    public GridHeaderJson() {

    }

    public List<String> getColNames() {
        return colNames;
    }

    public void setColNames(List<String> colNames) {
        this.colNames = colNames;
    }

    public List<Map<String, Object>> getColModel() {
        return colModel;
    }

    public void setColModel(List<Map<String, Object>> colModel) {
        this.colModel = colModel;
    }

    public int getRowNum() {
        return rowNum;
    }

    public void setRowNum(int rowNum) {
        this.rowNum = rowNum;
    }

    public String getSortname() {
        return sortname;
    }

    public void setSortname(int sortname) {
        this.sortname = String.valueOf(sortname);
    }

    public void setSortname(String sortname) {
        this.sortname = sortname;
    }

    public String getSortorder() {
        return sortorder;
    }

    public void setSortorder(String sortorder) {
        this.sortorder = sortorder;
    }

    public String getRecordtext() {
        return recordtext;
    }

    public void setRecordtext(String recordtext) {
        this.recordtext = recordtext;
    }

    public String getEmptyrecords() {
        return emptyrecords;
    }

    public void setEmptyrecords(String emptyrecords) {
        this.emptyrecords = emptyrecords;
    }
}

==> HinemosWebClient_src-2.0.2.tar.gz: HinemosWebClient_src-2.0.2/src/com/necsoft/hinemos/webclient/json/GridHeaderJson.java <==
/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.json;

import java.util.List;
import java.util.Map;

public class GridHeaderJson extends CommonJson {
    private List<String> colNames;

    private List<Map<String, Object>> colModel;

    private int rowNum;

    private String sortname;

    private String sortorder;

    private String recordtext;

    private String emptyrecords;

    /** 検索件数は最大表示件数を超える時の表示文字列 */
    private String exceedrecord;

    public GridHeaderJson() {

    }

    public List<String> getColNames() {
        return colNames;
    }

    public void setColNames(List<String> colNames) {
        this.colNames = colNames;
    }

    public List<Map<String, Object>> getColModel() {
        return colModel;
    }

    public void setColModel(List<Map<String, Object>> colModel) {
        this.colModel = colModel;
    }

    public int getRowNum() {
        return rowNum;
    }

    public void setRowNum(int rowNum) {
        this.rowNum = rowNum;
    }

    public String getSortname() {
        return sortname;
    }

    public void setSortname(int sortname) {
        this.sortname = String.valueOf(sortname);
    }

    public void setSortname(String sortname) {
        this.sortname = sortname;
    }

    public String getSortorder() {
        return sortorder;
    }

    public void setSortorder(String sortorder) {
        this.sortorder = sortorder;
    }

    public String getRecordtext() {
        return recordtext;
    }

    public void setRecordtext(String recordtext) {
        this.recordtext = recordtext;
    }

    public String getEmptyrecords() {
        return emptyrecords;
    }

    public void setEmptyrecords(String emptyrecords) {
        this.emptyrecords = emptyrecords;
    }

    public String getExceedrecord() {
        return exceedrecord;
    }

    public void setExceedrecord(String exceedrecord) {
        this.exceedrecord = exceedrecord;
    }

}
